@@ -1,6 +1,7 @@
 gompi_fun <- function(t, y, par) {
   y <- y[1]
   r <- par$r
-  dy <- y * r * (log(1) - log(y))
+  K <- par$K
+  dy <- y * r * (log(K) - log(y))
   return(list(c(dy)))
 }
