@@ -1,6 +1,7 @@
 logi_fun <- function(t, y, par) {
   y <- y[1]
   r <- par$r
-  dy <- y * r * (1 - y)
+  K <- par$K
+  dy <- y * r * (K - y)
   return(list(c(dy)))
 }
